# ViSound

Library to convert images to sounds.

## Introduction

This is just a standalone library for use in other programs that can make use of `ViSound` capabilities. On it's own `ViSound` doesn't do anything. You have to use it in some way to get the output and play the audio yourself.

## Features

* Sonify images in a number of different ways
* Output the audio to a file

## Traversal Modes

You can traverse the given input images in different ways to get different audio output. The following modes are currently supported.

* Left To Right
* Right to Left

# TODO

- [ ] Traversal
  - [ ] Circular inward
  - [ ] Circular outward
- [ ] Apply effects to the output audio
- [ ] Allow for custom pixel to frequency mapping
